@@ -1,5 +1,6 @@
 MCA <- function (X, ncp = 5, ind.sup = NULL, quanti.sup = NULL, quali.sup = NULL, graph = TRUE, axes=c(1,2),row.w=NULL) {
 
+    X <- as.data.frame(X)
     if (is.null(rownames(X))) rownames(X) = 1:nrow(X)
     if (is.null(colnames(X))) colnames(X) = paste("V",1:ncol(X),sep="")
     for (j in 1:ncol(X)) if (colnames(X)[j]=="") colnames(X)[j] = paste("V",j,sep="")
@@ -82,8 +83,6 @@ MCA <- function (X, ncp = 5, ind.sup = NULL, quanti.sup = NULL, quali.sup = NULL
     class(res.mca) <- c("MCA", "list")
     if (graph) {
       plot.MCA(res.mca,axes=axes)
-      plot.MCA(res.mca, invisible = c("ind","ind.sup"),axes=axes)
-      plot.MCA(res.mca, invisible = c("var","quali.sup"),axes=axes)
     }
     return(res.mca)
 }
