@@ -2,16 +2,12 @@ plot.MCA <- function (x, axes = c(1, 2),
     xlim = NULL, ylim = NULL, invisible = NULL, 
     col.ind = "blue", col.var = "red", col.quali.sup = "darkred",
     col.ind.sup = "darkblue", col.quanti.sup = "black",
-    label="all", cex = 1, title = NULL, habillage = "none", ...){
+    label="all", cex = 1, title = NULL, habillage = "none", palette=NULL, new.plot=TRUE, ...){
     
     res.mca <- x
     if (!inherits(res.mca, "MCA")) stop("non convenient data")
 
-    color = c("black","red","green3","blue",
-      "cyan","magenta","darkgray","darkgoldenrod","darkgreen","violet","turquoise","orange","lightpink","lavender","yellow","lightgreen","lightgrey",
-      "lightblue","darkkhaki", "darkmagenta","darkolivegreen","lightcyan", "darkorange",
-      "darkorchid","darkred","darksalmon","darkseagreen","darkslateblue","darkslategray","darkslategrey",
-      "darkturquoise","darkviolet", "lightgray","lightsalmon","lightyellow", "maroon")
+    if (is.null(palette)) palette(c("black","red","green3","blue",      "cyan","magenta","darkgray","darkgoldenrod","darkgreen","violet","turquoise","orange","lightpink","lavender","yellow","lightgreen","lightgrey","lightblue","darkkhaki", "darkmagenta","darkolivegreen","lightcyan", "darkorange", "darkorchid","darkred","darksalmon","darkseagreen","darkslateblue","darkslategray","darkslategrey","darkturquoise","darkviolet", "lightgray","lightsalmon","lightyellow", "maroon"))
 
     lab.ind <- lab.var <- lab.quali.sup <- lab.ind.sup <- FALSE
     if(length(label)==1 && label=="all") lab.ind <- lab.var <- lab.quali.sup <- lab.ind.sup <-TRUE
@@ -71,20 +67,20 @@ plot.MCA <- function (x, axes = c(1, 2),
           aux = 1
           col.var = NULL
           for (j in res.mca$call$quali) {
-            col.var <- c(col.var,rep(color[aux],nlevels(res.mca$call$X[,j])))
+            col.var <- c(col.var,rep(aux,nlevels(res.mca$call$X[,j])))
             aux = aux + 1
           }
           if (!is.null(res.mca$call$quali.sup)){
             col.quali.sup = NULL
             for (j in res.mca$call$quali.sup) {
-              col.quali.sup <- c(col.quali.sup,rep(color[aux],nlevels(res.mca$call$X[,j])))
+              col.quali.sup <- c(col.quali.sup,rep(aux,nlevels(res.mca$call$X[,j])))
               aux = aux + 1
             }
           }
         }
         if ((habillage != "none")&(habillage != "quali")) {
           if (!is.factor(res.mca$call$X[,habillage])) stop("The variable ", habillage, " is not qualitative")
-          col.ind <- color[as.numeric(as.factor(res.mca$call$X[, habillage]))]
+          col.ind <- as.numeric(as.factor(res.mca$call$X[, habillage]))
           n.mod <- nlevels(as.factor(res.mca$call$X[, habillage]))
           col.ind.sup <- col.ind[res.mca$call$ind.sup]
           if (!is.null(res.mca$call$ind.sup)) col.ind <- col.ind[-res.mca$call$ind.sup]
@@ -96,31 +92,31 @@ plot.MCA <- function (x, axes = c(1, 2),
     if (is.null(title)) titre <- "MCA factor map"
     else sub.titre <- "MCA factor map"
     if (is.na(test.invisible[1])|is.na(test.invisible[2])|is.na(test.invisible[4])|is.na(test.invisible[5])) {
-      get(getOption("device"))(width=8,height=8)
+      if (new.plot) get(getOption("device"))(width=8,height=8)
       plot(0, 0, main = titre, xlab = paste("Dim ",axes[1]," (",signif(res.mca$eig[axes[1],2],4),"%)",sep=""), ylab = paste("Dim ",axes[2]," (",signif(res.mca$eig[axes[2],2],4),"%)",sep=""), xlim = xlim, ylim = ylim, col = "white", asp=1, cex=cex)
       if (!is.null(sub.titre)) title(sub = sub.titre, cex.sub = cex, font.sub = 2, col.sub = "steelblue4", adj = 0, line = 3.8)
       abline(v=0,lty=2, cex=cex)
       abline(h=0,lty=2, cex=cex)
       if (is.na(test.invisible[1])) {
           points(coord.ind, pch = 16, col = col.ind)
-          if (lab.ind) text(coord.ind[, 1], y = coord.ind[, 2], labels = rownames(coord.ind), pos = 3, col = col.ind)
+          if (lab.ind) text(coord.ind[, 1], y = coord.ind[, 2], labels = rownames(coord.ind), pos = 3, col = col.ind, cex=cex)
       }
       if (is.na(test.invisible[2])) {
-          points(coord.var[, 1], y = coord.var[, 2], pch = 17, col = col.var)
-          if (lab.var) text(coord.var[, 1], y = coord.var[, 2], labels = rownames(coord.var), pos = 3, col = col.var)
+          points(coord.var[, 1], y = coord.var[, 2], pch = 17, col = col.var, cex=cex)
+          if (lab.var) text(coord.var[, 1], y = coord.var[, 2], labels = rownames(coord.var), pos = 3, col = col.var, cex=cex)
       }
       if (!is.null(res.mca$quali.sup) & is.na(test.invisible[5])) {
-          points(coord.quali.sup[, 1], y = coord.quali.sup[, 2], pch = 17, col = col.quali.sup)
-          if (lab.quali.sup) text(coord.quali.sup[, 1], y = coord.quali.sup[, 2], labels = rownames(coord.quali.sup), pos = 3, col = col.quali.sup)
+          points(coord.quali.sup[, 1], y = coord.quali.sup[, 2], pch = 17, col = col.quali.sup, cex=cex)
+          if (lab.quali.sup) text(coord.quali.sup[, 1], y = coord.quali.sup[, 2], labels = rownames(coord.quali.sup), pos = 3, col = col.quali.sup, cex=cex)
       }
       if (!is.null(res.mca$ind.sup) & is.na(test.invisible[4])) {
-          points(coord.ind.sup[, 1], y = coord.ind.sup[, 2], pch = 16, col = col.ind.sup)
-          if (lab.ind.sup) text(coord.ind.sup[, 1], y = coord.ind.sup[, 2], labels = rownames(coord.ind.sup), pos = 3, col = col.ind.sup)
+          points(coord.ind.sup[, 1], y = coord.ind.sup[, 2], pch = 16, col = col.ind.sup, cex=cex)
+          if (lab.ind.sup) text(coord.ind.sup[, 1], y = coord.ind.sup[, 2], labels = rownames(coord.ind.sup), pos = 3, col = col.ind.sup, cex=cex)
       }
-      if ((habillage != "none")&(habillage != "quali")&(is.na(test.invisible[1])|is.na(test.invisible[2])))  legend("topleft",legend= levels(res.mca$call$X[,habillage]),text.col= color[1:n.mod],cex=0.8)
+      if ((habillage != "none")&(habillage != "quali")&(is.na(test.invisible[1])|is.na(test.invisible[2])))  legend("topleft",legend= levels(res.mca$call$X[,habillage]),text.col= 1:n.mod,cex=0.8)
     }
     if (!is.null(res.mca$quanti.sup)&is.na(test.invisible[3])) {
-      get(getOption("device"))(width=8,height=8)
+      if (new.plot) get(getOption("device"))(width=8,height=8)
       plot(0, 0, main = "Supplementary variables on the MCA factor map", xlab = paste("Dim ",axes[1]," (",signif(res.mca$eig[axes[1],2],4),"%)",sep=""), ylab = paste("Dim ",axes[2]," (",signif(res.mca$eig[axes[2],2],4),"%)",sep=""), xlim = c(-1.1,1.1), ylim = c(-1.1,1.1), col = "white", asp=1, cex=cex)
       abline(v=0,lty=2, cex=cex)
       abline(h=0,lty=2, cex=cex)
