@@ -4,7 +4,7 @@ print.HMFA <- function (x, file = NULL, sep = ";", ...){
     cat("**Results of the Hierarchical Multiple Factor Analysis (HMFA)**\n\n")
     cat("There are", nrow(res.hmfa$ind$coord), "individuals\n\n")
     cat("*Results are available in the following objects :\n\n")
-    res <- array("", c(22, 2), list(1:22, c("nom", "description")))
+    res <- array("", c(22, 2), list(1:22, c("name", "description")))
     res[1, ] <- c("$eig", "eigenvalues")
     res[2, ] <- c("$group", "results for all the groups")
     res[3, ] <- c("$ind", "results for the individuals")
